Installation
=================

SayTeX exists as a Python 3 package, which allows you to use the SayTeX functionality
from any Python module or script.

Install the ``saytex`` package using PyPI:

.. code-block:: bash

    pip install saytex

Note that the ``saytex`` package only supports Python 3. If the above
command gives an error, run ``pip -V`` and make sure it says Python 3. If
it does not, try running ``pip3`` instead.
